#!/usr/bin/env python3
#
# Copyright (c) 2024 Stormux
# Copyright (c) 2010-2012 The Orca Team
# Copyright (c) 2012 Igalia, S.L.
# Copyright (c) 2005-2010 Sun Microsystems Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
# Boston MA  02110-1301 USA.
#
# Fork of Orca Screen Reader (GNOME)
# Original source: https://gitlab.gnome.org/GNOME/orca

"""Utilities for Sleep Mode. Helps ensure we do nothing. When nothing is done, nothing is left undone."""

__id__        = "$Id$"
__version__   = "$Revision$"
__date__      = "$Date$"
__copyright__ = "Copyright (c) 2024 Stormux"
__license__   = "LGPL"

import cthulhu.debug as debug
import cthulhu.script_utilities as script_utilities

class Utilities(script_utilities.Utilities):
    """Utilities class for the sleep-mode script."""

    def willEchoCharacter(self, event):
        """Returns True if we'll echo this character."""
        
        msg = "SLEEP MODE: Will not echo character."
        debug.printMessage(debug.LEVEL_INFO, msg, True)
        return False

    def displayRegionChanged(self, obj, start, end, mode):
        """Don't track changes in sleep mode."""
        
        msg = "SLEEP MODE: Will not track display changes."
        debug.printMessage(debug.LEVEL_INFO, msg, True)
        return False

    def shouldPresentContext(self):
        """Don't present context in sleep mode."""
        
        msg = "SLEEP MODE: Will not present context."
        debug.printMessage(debug.LEVEL_INFO, msg, True)
        return False
